/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package com.evasion.plugin.content;

import com.evasion.ejb.local.StaticPageManagerLocal;
import com.evasion.ejb.local.UserAuthServiceLocal;
import com.evasion.entity.StaticPage;
import com.evasion.entity.security.User;
import com.evasion.exception.PersistenceViolationException;
import java.util.Date;
import java.util.List;
import javax.ejb.EJB;
import javax.ejb.Local;
import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 * @author sebastien.glon
 */
@Stateless
@Local(value = StaticPageManagerLocal.class)
public class StaticPageManager implements StaticPageManagerLocal {

    /** LOGGER  */
    private static final Logger LOGGER = LoggerFactory.getLogger(
            StaticPageManager.class);
    @EJB
    UserAuthServiceLocal userService;
    
    @PersistenceContext(unitName = "EvasionPU")
    private EntityManager em;

    protected StaticPageManager(EntityManager em) {
        this.em = em;
    }

    public StaticPageManager() {
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public StaticPage savePage(StaticPage page) throws PersistenceViolationException {
        StaticPage newPage = page;
        page.setDateMaj(new Date());
        try {
            if (page.getId() == null) {
                em.persist(newPage);
            } else {
                newPage = em.merge(newPage);
            }
            em.flush();
        } catch (Exception e) {
            throw new PersistenceViolationException("Erreur dans la validation de la page statique", e.fillInStackTrace());
        }
        return newPage;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public StaticPage createPage(StaticPage page, String userName) throws PersistenceViolationException {
        if (page.getId() != null) {
            throw new PersistenceViolationException("Cette méthode ne peut être utilisé pour une page déja existente");
        }
        User user = userService.findUserByUserName(userName);
        page.setUser(user);
        return savePage(page);
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public void deletePage(StaticPage p) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public List<StaticPage> listAll() {
        List<StaticPage> list;
        Query query = em.createNamedQuery(StaticPage.FIND_ALL);
        list = query.getResultList();
//        for (StaticPage page : list) {
//            em.refresh(page);
//        }
//        list.size();
        return list;
    }

    /**
     * {@inheritDoc }
     */
    @TransactionAttribute(TransactionAttributeType.NEVER)
    @Override
    public StaticPage getStaticPage(Long id) {
        StaticPage page = em.find(StaticPage.class, id);
        if (page != null && page.getCorps() != null) {
            page.getCorps().length();
        }
        return page;
    }
}
